@@ -1,4 +1,4 @@
-from controller.client import Client
+from fgp.controller.client import Client
 from typing import List
 from urllib.parse import urlparse
 from .device import Device
